searchNodes=[{"doc":"Machete provides ergonomic match operators to help make your ExUnit tests more literate The easiest way to explain Machete is to show it in action: defmodule ExampleTest do use ExUnit.Case use Machete test &quot;example test&quot; do response = %{ id : 1 , name : &quot;Moe Fonebone&quot; , is_admin : false , created_at : DateTime . utc_now ( ) } assert response ~&gt; %{ id : integer ( positive : true ) , name : string ( ) , is_admin : false , created_at : datetime ( roughly : :now , time_zone : :utc ) } end end At its heart, Machete provides the following two things: A new ~&gt; operator (the 'squiggle arrow') that does flexible matching of its left operator with its right operator A set of parametric matchers such as string() or integer() which can match against general types These building blocks let you define test expectations that can match data against any combination of literals, variables, or parametrically defined matchers When your matches fail, Machete provides useful error messages in ExUnit that point you directly at any failing matches using jq syntax Matching literals &amp; variables Machete matches directly against literals &amp; variables. The following examples will all match: # Builtin type literals all match themselves: assert 1 ~&gt; 1 assert &quot;abc&quot; ~&gt; &quot;abc&quot; # Comparison is strict, using === semantics: refute 1.0 ~&gt; 1 refute &quot;123&quot; ~&gt; 123 # Variables &#39;just work&#39; everywhere; no pinning required! a_number = 1 assert a_number ~&gt; 1 assert 1 ~&gt; a_number assert a_number ~&gt; a_number # Date-like types are compared using the relevant `compare/2` function: assert ~D[2021-02-01] ~&gt; ~D[2021-02-01] # Regexes match using =~ semantics: assert &quot;abc&quot; ~&gt; ~r/abc/ Type-based matchers Machete comes with parametric matchers defined for a variety of types. Many of these matchers take optional arguments to further refine matches (for example, integer(positive: true) will match positive integers). For details, see the documentation of specific matchers below. The following matchers are defined by Machete: atom() matches atoms boolean() matches boolean values date() matches Date instances datetime() matches DateTime instances falsy() matches falsy values float() matches float values integer() matches integer values iso8601_datetime() matches ISO8601 formatted strings is_a() matches against a struct type naive_datetime() matches NaiveDateTime instances pid() matches process IDs port() matches Erlang ports reference() matches Erlang references string() matches UTF-8 binaries struct_like() matches structs based on type and a set of fields term() matches any term (including nil) time() matches Time instances truthy() matches truthy values Collection matchers Collections can be matched as literals, with their contents being recursively matched. This usage requires knowing the exact shape of the collection up front, and may not always be suitable. For cases where you may need more flexible collection matching, Machete provides the following matchers: in_any_order() matches lists in any order indifferent_access() matches maps, considering similar atom and string keys to be equivalent list() matches lists, with optional constraints on element type &amp; list length map() matches maps, with optional constraints on key and value types &amp; map size subset() matches maps against its intersection with a (possibly larger) map superset() matches maps against its intersection with a (possibly smaller) map Miscellaneous matchers all() matches the value against a set of matchers, requiring all of them to match any() matches the value against a set of matchers, requiring at least one of them to match maybe() matches using a specified matcher, but also matches nil none() matches the value against a set of matchers, requiring none of them to match Write your own matchers Implementing your own matchers is easy! Behind the scenes, parametric matchers are plain functions which return structs conforming to the Machete.Matchable protocol. You can implement your own matchers by doing the same; a good place to start would be to look at something like the falsy matcher as a starting point. For more adhoc matchers, you can also define a function which returns the output of an existing matcher. For example, if you wanted to define a matcher named tags() which would match a (possibly empty) list of non-empty strings without whitespace, you could do so like so: def tags ( ) , do : list ( elements : string ( empty : false , whitespace : false ) ) assert %{ tags : [ &quot;cool&quot; , &quot;awesome&quot; , &quot;not_lame&quot; ] } ~&gt; %{ tags : tags ( ) } This allows you to easily DRY up your test expectations, keeping a centralized notion of what various formats in your data look like","ref":"Machete.html","title":"Machete","type":"module"},{"doc":"Brings the ~&gt; and ~&gt;&gt; operators into scope, along with assert/1 and refute/1 macros to be aware of them. Also brings the set of parameteric matchers listed above into scope. Typical use of this is to use Machete at the top of your ExUnit tests, taking care to place this after any use ExUnit... calls to ensure that the relevant assert/1 and refute/1 macros are properly scoped","ref":"Machete.html#__using__/1","title":"Machete.__using__/1","type":"macro"},{"doc":"Macros for use within the context of ExUnit tests, to provide ~&gt; awareness to assert/1 and refute/1 macros. Because macros cannot be defined in multiple modules, proper use of this module requires the user to take ExUnit.Assertions ' version of assert/1 and refute/1 out of scope, and to allow this module's versions of those macros to call through to ExUnit.Assertions ' version for conditions other than ~&gt; . See Machete.__using__/1 for details.","ref":"Machete.Assertions.html","title":"Machete.Assertions","type":"module"},{"doc":"A custom implementation of the assert/1 macro to provide support for useful errors on ~&gt; mismatches; all other patterns are passed through to ExUnit.Assertions.assert/1","ref":"Machete.Assertions.html#assert/1","title":"Machete.Assertions.assert/1","type":"macro"},{"doc":"A custom implementation of the refute/1 macro to provide support for useful errors on ~&gt; mismatches; all other patterns are passed through to ExUnit.Assertions.refute/1","ref":"Machete.Assertions.html#refute/1","title":"Machete.Assertions.refute/1","type":"macro"},{"doc":"Defines a protocol to determine how a given term may match against a type. The Machete.Matchable protocol is central to the Machete library, and conformance to it is necessary for any type to be used on the right hand side of a ~&gt; match","ref":"Machete.Matchable.html","title":"Machete.Matchable","type":"protocol"},{"doc":"Examines the value of the passed term and returns the way(s) in which it does not conform to the base type instance's requirements, expressed as a list of Machete.Mismatch structs. If there are no such mismatches (that is, if the passed term 'matches' against the base type instance), implementations of this protocol may return an empty list or nil ; they are semantically equivalent. Implementors of this protocol may be interested in the Machete.Mismatch.mismatch/2 function to easily create mismatches","ref":"Machete.Matchable.html#mismatches/2","title":"Machete.Matchable.mismatches/2","type":"function"},{"doc":"","ref":"Machete.Matchable.html#t:t/0","title":"Machete.Matchable.t/0","type":"type"},{"doc":"Data and functions to deal with representing mismatches","ref":"Machete.Mismatch.html","title":"Machete.Mismatch","type":"module"},{"doc":"Pretty prints the specified list of mismatches, in a manner suitable for presentation to the user","ref":"Machete.Mismatch.html#format_mismatches/2","title":"Machete.Mismatch.format_mismatches/2","type":"function"},{"doc":"Constructs an instance of Matchable.Mismatch with the given message and path, wrapped in a list and suitable for return from a Machete.Matchable.mismatches/2 call","ref":"Machete.Mismatch.html#mismatch/2","title":"Machete.Mismatch.mismatch/2","type":"function"},{"doc":"Describes the details of a mismatch","ref":"Machete.Mismatch.html#t:t/0","title":"Machete.Mismatch.t/0","type":"type"},{"doc":"Defines implementations for the ~&gt; and ~&gt;&gt; operators","ref":"Machete.Operators.html","title":"Machete.Operators","type":"module"},{"doc":"Matches data on the left hand side against matcher(s) on the right hand side. Matching is determined by calling the Machete.Matchable.mismatches/2 protocol function using the right hand side's implementation Examples: iex&gt; 1 ~&gt; 1 true iex&gt; 1 ~&gt; integer ( ) true iex&gt; &quot;1&quot; ~&gt; integer ( ) false iex&gt; %{ a : 1 , b : &quot;abc&quot; } ~&gt; %{ a : 1 , b : string ( ) } true Returns a boolean result indicating whether the left hand side matched against the right hand side","ref":"Machete.Operators.html#~%3E/2","title":"Machete.Operators.~>/2","type":"function"},{"doc":"Returns the list of mismatches between the left and right hand side arguments, determined by calling the Machete.Matchable.mismatches/2 protocol function using the right hand side's implementation Examples: iex&gt; 1 ~&gt;&gt; 1 [ ] iex&gt; 1 ~&gt;&gt; integer ( ) [ ] iex&gt; &quot;1&quot; ~&gt;&gt; integer ( ) [ % Machete.Mismatch { message : &quot; \\&quot; 1 \\&quot; is not an integer&quot; , path : [ ] } ] iex&gt; %{ a : 1 } ~&gt;&gt; %{ a : 2 } [ % Machete.Mismatch { message : &quot;1 is not equal to 2&quot; , path : [ :a ] } ] Returns a (possibly empty) list of Machete.Mismatch structs","ref":"Machete.Operators.html#~%3E%3E/2","title":"Machete.Operators.~>>/2","type":"function"},{"doc":"Defines a matcher that matches against a set of matchers, requiring all of them to match","ref":"Machete.AllMatcher.html","title":"Machete.AllMatcher","type":"module"},{"doc":"Matches against a set of matchers, requiring all of them to match Takes a list of matchers as its sole (mandatory) argument Examples: iex&gt; assert &quot;abc&quot; ~&gt; all ( [ term ( ) , string ( ) ] ) true iex&gt; refute :abc ~&gt; all ( [ term ( ) , string ( ) ] ) false","ref":"Machete.AllMatcher.html#all/1","title":"Machete.AllMatcher.all/1","type":"function"},{"doc":"Describes an instance of this matcher","ref":"Machete.AllMatcher.html#t:t/0","title":"Machete.AllMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches against a set of matchers, requiring at least one of them to match","ref":"Machete.AnyMatcher.html","title":"Machete.AnyMatcher","type":"module"},{"doc":"Matches against a set of matchers, requiring at least one of them to match Takes a list of matchers as its sole (mandatory) argument Examples: iex&gt; assert &quot;abc&quot; ~&gt; any ( [ string ( ) , integer ( ) ] ) true iex&gt; refute :abc ~&gt; any ( [ string ( ) , integer ( ) ] ) false","ref":"Machete.AnyMatcher.html#any/1","title":"Machete.AnyMatcher.any/1","type":"function"},{"doc":"Describes an instance of this matcher","ref":"Machete.AnyMatcher.html#t:t/0","title":"Machete.AnyMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches atom values","ref":"Machete.AtomMatcher.html","title":"Machete.AtomMatcher","type":"module"},{"doc":"Matches against atom values Takes no arguments Examples: iex&gt; assert :a ~&gt; atom ( ) true iex&gt; refute &quot;a&quot; ~&gt; atom ( ) false","ref":"Machete.AtomMatcher.html#atom/1","title":"Machete.AtomMatcher.atom/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.AtomMatcher.html#t:opts/0","title":"Machete.AtomMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.AtomMatcher.html#t:t/0","title":"Machete.AtomMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches boolean values","ref":"Machete.BooleanMatcher.html","title":"Machete.BooleanMatcher","type":"module"},{"doc":"Matches against boolean values Takes no arguments Examples: iex&gt; assert true ~&gt; boolean ( ) true iex&gt; assert true ~&gt; boolean ( ) true iex&gt; refute 1 ~&gt; boolean ( ) false iex&gt; refute nil ~&gt; boolean ( ) false","ref":"Machete.BooleanMatcher.html#boolean/1","title":"Machete.BooleanMatcher.boolean/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.BooleanMatcher.html#t:opts/0","title":"Machete.BooleanMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.BooleanMatcher.html#t:t/0","title":"Machete.BooleanMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches Date values","ref":"Machete.DateMatcher.html","title":"Machete.DateMatcher","type":"module"},{"doc":"Matches against Date values Takes the following arguments: exactly : Requires the matched Date to be exactly equal to the specified Date. The atom :today can be used to use today as the specified Date roughly : Requires the matched Date to be within +/- 1 day of the specified Date. The atom :today can be used to use today as the specified Date before : Requires the matched Date to be before or equal to the specified Date. The atom :today can be used to use today as the specified Date after : Requires the matched Date to be after or equal to the specified Date. The atom :today can be used to use today as the specified Date Examples: iex&gt; assert Date . utc_today ( ) ~&gt; date ( ) true iex&gt; assert Date . utc_today ( ) ~&gt; date ( exactly : :today ) true iex&gt; assert ~D[2020-01-01] ~&gt; date ( exactly : ~D[2020-01-01] ) true iex&gt; assert Date . utc_today ( ) ~&gt; date ( roughly : :today ) true iex&gt; assert ~D[2020-01-01] ~&gt; date ( roughly : ~D[2020-01-02] ) true iex&gt; assert ~D[2020-01-01] ~&gt; date ( before : :today ) true iex&gt; assert ~D[2020-01-01] ~&gt; date ( before : ~D[3000-01-01] ) true iex&gt; assert ~D[3000-01-01] ~&gt; date ( after : :today ) true iex&gt; assert ~D[3000-01-01] ~&gt; date ( after : ~D[2020-01-01] ) true","ref":"Machete.DateMatcher.html#date/1","title":"Machete.DateMatcher.date/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.DateMatcher.html#t:opts/0","title":"Machete.DateMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.DateMatcher.html#t:t/0","title":"Machete.DateMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches DateTime values","ref":"Machete.DateTimeMatcher.html","title":"Machete.DateTimeMatcher","type":"module"},{"doc":"Matches against DateTime values Takes the following arguments: precision : Requires the matched DateTime to have the specified microsecond precision time_zone : Requires the matched DateTime to have the specified time zone. The atom :utc can be used to specify the &quot;Etc/UTC&quot; time zone exactly : Requires the matched DateTime to be exactly equal to the specified DateTime roughly : Requires the matched DateTime to be within +/- 10 seconds of the specified DateTime. The atom :now can be used to use the current time as the specified DateTime before : Requires the matched DateTime to be before or equal to the specified DateTime. The atom :now can be used to use the current time as the specified DateTime after : Requires the matched DateTime to be after or equal to the specified DateTime. The atom :now can be used to use the current time as the specified DateTime Examples: iex&gt; assert DateTime . utc_now ( ) ~&gt; datetime ( ) true iex&gt; assert DateTime . utc_now ( ) ~&gt; datetime ( precision : 6 ) true iex&gt; assert DateTime . utc_now ( ) ~&gt; datetime ( time_zone : :utc ) true iex&gt; assert DateTime . utc_now ( ) ~&gt; datetime ( time_zone : &quot;Etc/UTC&quot; ) true iex&gt; assert ~U[2020-01-01 00:00:00.000000Z] ~&gt; datetime ( exactly : ~U[2020-01-01 00:00:00.000000Z] ) true iex&gt; assert DateTime . utc_now ( ) ~&gt; datetime ( roughly : :now ) true iex&gt; assert ~U[2020-01-01 00:00:00.000000Z] ~&gt; datetime ( roughly : ~U[2020-01-01 00:00:05.000000Z] ) true iex&gt; assert ~U[2020-01-01 00:00:00.000000Z] ~&gt; datetime ( before : :now ) true iex&gt; assert ~U[2020-01-01 00:00:00.000000Z] ~&gt; datetime ( before : ~U[3000-01-01 00:00:00.000000Z] ) true iex&gt; assert ~U[3000-01-01 00:00:00.000000Z] ~&gt; datetime ( after : :now ) true iex&gt; assert ~U[3000-01-01 00:00:00.000000Z] ~&gt; datetime ( after : ~U[2020-01-01 00:00:00.000000Z] ) true","ref":"Machete.DateTimeMatcher.html#datetime/1","title":"Machete.DateTimeMatcher.datetime/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.DateTimeMatcher.html#t:opts/0","title":"Machete.DateTimeMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.DateTimeMatcher.html#t:t/0","title":"Machete.DateTimeMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches falsy values","ref":"Machete.FalsyMatcher.html","title":"Machete.FalsyMatcher","type":"module"},{"doc":"Matches against falsy values Takes no arguments Examples: iex&gt; assert false ~&gt; falsy ( ) true iex&gt; assert nil ~&gt; falsy ( ) true iex&gt; refute true ~&gt; falsy ( ) false","ref":"Machete.FalsyMatcher.html#falsy/1","title":"Machete.FalsyMatcher.falsy/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.FalsyMatcher.html#t:opts/0","title":"Machete.FalsyMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.FalsyMatcher.html#t:t/0","title":"Machete.FalsyMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches float values","ref":"Machete.FloatMatcher.html","title":"Machete.FloatMatcher","type":"module"},{"doc":"Matches against float values Takes the following arguments: positive : When true , requires the matched float be positive or zero negative : When true , requires the matched float be negative or zero nonzero : When true , requires the matched float be nonzero min : Requires the matched float be greater than or equal to the specified value max : Requires the matched float be less than or equal to the specified value Examples: iex&gt; assert 1.0 ~&gt; float ( ) true iex&gt; assert 1.0 ~&gt; float ( positive : true ) true iex&gt; assert 0.0 ~&gt; float ( positive : true ) true iex&gt; assert - 1.0 ~&gt; float ( positive : false ) true iex&gt; refute 0.0 ~&gt; float ( positive : false ) false iex&gt; assert - 1.0 ~&gt; float ( negative : true ) true iex&gt; assert 0.0 ~&gt; float ( negative : true ) true iex&gt; assert 1.0 ~&gt; float ( negative : false ) true iex&gt; refute 0.0 ~&gt; float ( negative : false ) false iex&gt; assert 1.0 ~&gt; float ( nonzero : true ) true iex&gt; assert 0.0 ~&gt; float ( nonzero : false ) true iex&gt; assert 2.0 ~&gt; float ( min : 2.0 ) true iex&gt; assert 2.0 ~&gt; float ( max : 2.0 ) true","ref":"Machete.FloatMatcher.html#float/1","title":"Machete.FloatMatcher.float/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.FloatMatcher.html#t:opts/0","title":"Machete.FloatMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.FloatMatcher.html#t:t/0","title":"Machete.FloatMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches ISO8601 formatted strings","ref":"Machete.ISO8601DateTimeMatcher.html","title":"Machete.ISO8601DateTimeMatcher","type":"module"},{"doc":"Matches against ISO8601 formatted strings Takes the following arguments: precision : Requires the matched ISO8601 string to have the specified microsecond precision time_zone : Requires the matched ISO8601 string to have the specified time zone. The atom :utc can be used to specify the &quot;Etc/UTC&quot; time zone exactly : Requires the matched ISO8601 string to be exactly equal to the specified DateTime roughly : Requires the matched ISO8601 string to be within +/- 10 seconds of the specified DateTime. This values must be specified as a DateTime. The atom :now can be used to use the current time as the specified DateTime before : Requires the matched ISO8601 string to be before or equal to the specified DateTime. This values must be specified as a DateTime. The atom :now can be used to use the current time as the specified DateTime after : Requires the matched ISO8601 string to be after or equal to the specified DateTime. This values must be specified as a DateTime. The atom :now can be used to use the current time as the specified DateTime Examples: iex&gt; assert &quot;2020-01-01T00:00:00.000000Z&quot; ~&gt; iso8601_datetime ( ) true iex&gt; assert &quot;2020-01-01T00:00:00.000000Z&quot; ~&gt; iso8601_datetime ( precision : 6 ) true iex&gt; assert &quot;2020-01-01T00:00:00.000000Z&quot; ~&gt; iso8601_datetime ( time_zone : :utc ) true iex&gt; assert &quot;2020-01-01T00:00:00.000000Z&quot; ~&gt; iso8601_datetime ( time_zone : &quot;Etc/UTC&quot; ) true iex&gt; assert &quot;2020-01-01 00:00:00.000000Z&quot; ~&gt; iso8601_datetime ( exactly : ~U[2020-01-01 00:00:00.000000Z] ) true iex&gt; assert DateTime . utc_now ( ) |&gt; DateTime . to_iso8601 ( ) ~&gt; iso8601_datetime ( roughly : :now ) true iex&gt; assert &quot;2020-01-01T00:00:00.000000Z&quot; ~&gt; iso8601_datetime ( roughly : ~U[2020-01-01 00:00:05.000000Z] ) true iex&gt; assert &quot;2020-01-01T00:00:00.000000Z&quot; ~&gt; iso8601_datetime ( before : :now ) true iex&gt; assert &quot;2020-01-01T00:00:00.000000Z&quot; ~&gt; iso8601_datetime ( before : ~U[3000-01-01 00:00:00.000000Z] ) true iex&gt; assert &quot;3000-01-01T00:00:00.000000Z&quot; ~&gt; iso8601_datetime ( after : :now ) true iex&gt; assert &quot;3000-01-01T00:00:00.000000Z&quot; ~&gt; iso8601_datetime ( after : ~U[2020-01-01 00:00:00.000000Z] ) true","ref":"Machete.ISO8601DateTimeMatcher.html#iso8601_datetime/1","title":"Machete.ISO8601DateTimeMatcher.iso8601_datetime/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.ISO8601DateTimeMatcher.html#t:opts/0","title":"Machete.ISO8601DateTimeMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.ISO8601DateTimeMatcher.html#t:t/0","title":"Machete.ISO8601DateTimeMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches lists in any order","ref":"Machete.InAnyOrderMatcher.html","title":"Machete.InAnyOrderMatcher","type":"module"},{"doc":"Matches lists in any order. Matchers are applied in all possible orders until one matches; this can be exponentially expensive for long lists. Examples: iex&gt; assert [ 1 ] ~&gt; in_any_order ( [ 1 ] ) true iex&gt; assert [ 2 , 1 ] ~&gt; in_any_order ( [ 1 , 2 ] ) true iex&gt; assert [ 1 , &quot;a&quot; , :a ] ~&gt; in_any_order ( [ string ( ) , atom ( ) , integer ( ) ] ) true iex&gt; refute [ 1 , 2 ] ~&gt; in_any_order ( [ 1 , 3 ] ) false","ref":"Machete.InAnyOrderMatcher.html#in_any_order/1","title":"Machete.InAnyOrderMatcher.in_any_order/1","type":"function"},{"doc":"Describes an instance of this matcher","ref":"Machete.InAnyOrderMatcher.html#t:t/0","title":"Machete.InAnyOrderMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches indifferently (that is, it considers similar atom and string keys to be equivalent)","ref":"Machete.IndifferentAccessMatcher.html","title":"Machete.IndifferentAccessMatcher","type":"module"},{"doc":"Defines a matcher that matches indifferently (that is, it considers similar atom and string keys to be equivalent) Takes a map as its sole (mandatory) argument Examples: iex&gt; assert %{ a : 1 } ~&gt; indifferent_access ( %{ a : 1 } ) true iex&gt; assert %{ &quot;a&quot; =&gt; 1 } ~&gt; indifferent_access ( %{ &quot;a&quot; =&gt; 1 } ) true iex&gt; assert %{ a : 1 } ~&gt; indifferent_access ( %{ &quot;a&quot; =&gt; 1 } ) true iex&gt; assert %{ &quot;a&quot; =&gt; 1 } ~&gt; indifferent_access ( %{ a : 1 } ) true iex&gt; assert %{ 1 =&gt; 1 } ~&gt; indifferent_access ( %{ 1 =&gt; 1 } ) true","ref":"Machete.IndifferentAccessMatcher.html#indifferent_access/1","title":"Machete.IndifferentAccessMatcher.indifferent_access/1","type":"function"},{"doc":"Describes an instance of this matcher","ref":"Machete.IndifferentAccessMatcher.html#t:t/0","title":"Machete.IndifferentAccessMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches integer values","ref":"Machete.IntegerMatcher.html","title":"Machete.IntegerMatcher","type":"module"},{"doc":"Matches against integer values Takes the following arguments: positive : When true , requires the matched integer be positive or zero negative : When true , requires the matched integer be negative or zero nonzero : When true , requires the matched integer be nonzero min : Requires the matched integer be greater than or equal to the specified value max : Requires the matched integer be less than or equal to the specified value Examples: iex&gt; assert 1 ~&gt; integer ( ) true iex&gt; assert 1 ~&gt; integer ( positive : true ) true iex&gt; assert 0 ~&gt; integer ( positive : true ) true iex&gt; assert - 1 ~&gt; integer ( positive : false ) true iex&gt; refute 0 ~&gt; integer ( positive : false ) false iex&gt; assert - 1 ~&gt; integer ( negative : true ) true iex&gt; assert 0 ~&gt; integer ( negative : true ) true iex&gt; assert 1 ~&gt; integer ( negative : false ) true iex&gt; refute 0 ~&gt; integer ( negative : false ) false iex&gt; assert 1 ~&gt; integer ( nonzero : true ) true iex&gt; assert 0 ~&gt; integer ( nonzero : false ) true iex&gt; assert 2 ~&gt; integer ( min : 2 ) true iex&gt; assert 2 ~&gt; integer ( max : 2 ) true","ref":"Machete.IntegerMatcher.html#integer/1","title":"Machete.IntegerMatcher.integer/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.IntegerMatcher.html#t:opts/0","title":"Machete.IntegerMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.IntegerMatcher.html#t:t/0","title":"Machete.IntegerMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches againt a type of struct","ref":"Machete.IsAMatcher.html","title":"Machete.IsAMatcher","type":"module"},{"doc":"Matches against a type of struct. Similar to Kernel.struct/2 , the argument may be a module name or a struct instance. In both cases, the match is concerned solely with type equivalence. Examples: iex&gt; assert % URI { } ~&gt; is_a ( URI ) true iex&gt; assert % URI { } ~&gt; is_a ( % URI { } ) true iex&gt; refute % URI { } ~&gt; is_a ( DateTime ) false","ref":"Machete.IsAMatcher.html#is_a/1","title":"Machete.IsAMatcher.is_a/1","type":"function"},{"doc":"Describes an instance of this matcher","ref":"Machete.IsAMatcher.html#t:t/0","title":"Machete.IsAMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches lists","ref":"Machete.ListMatcher.html","title":"Machete.ListMatcher","type":"module"},{"doc":"Matches lists. Useful for cases where you wish to match against the general shape / size of a list, but cannot match against a literal list Takes the following arguments: elements : A matcher to use against all elements in the list length : Requires the matched list to be exactly the specified length min : Requires the matched list to be greater than or equal to the specified length max : Requires the matched list to be less than or equal to the specified length Examples: iex&gt; assert [ 1 ] ~&gt; list ( elements : integer ( ) ) true iex&gt; assert [ 1 ] ~&gt; list ( length : 1 ) true iex&gt; assert [ 1 ] ~&gt; list ( min : 1 ) true iex&gt; assert [ 1 ] ~&gt; list ( max : 2 ) true","ref":"Machete.ListMatcher.html#list/1","title":"Machete.ListMatcher.list/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.ListMatcher.html#t:opts/0","title":"Machete.ListMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.ListMatcher.html#t:t/0","title":"Machete.ListMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches maps","ref":"Machete.MapMatcher.html","title":"Machete.MapMatcher","type":"module"},{"doc":"Matches maps. Useful for cases where you wish to match against the general shape / size of a map, but cannot match against a literal map (or use the Machete.Superset / Machete.Subset matchers) Takes the following arguments: keys : A matcher to use against all keys in the map values : A matcher to use against all values in the map size : Requires the matched map to be exactly the specified size min : Requires the matched map to be greater than or equal to the specified size max : Requires the matched map to be less than or equal to the specified size Examples: iex&gt; assert %{ a : 1 } ~&gt; map ( ) true iex&gt; assert %{ a : 1 } ~&gt; map ( keys : atom ( ) ) true iex&gt; assert %{ a : 1 } ~&gt; map ( values : integer ( ) ) true iex&gt; assert %{ a : 1 } ~&gt; map ( size : 1 ) true iex&gt; assert %{ a : 1 } ~&gt; map ( min : 1 ) true iex&gt; assert %{ a : 1 } ~&gt; map ( max : 2 ) true","ref":"Machete.MapMatcher.html#map/1","title":"Machete.MapMatcher.map/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.MapMatcher.html#t:opts/0","title":"Machete.MapMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.MapMatcher.html#t:t/0","title":"Machete.MapMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches against another matcher &amp; also matches nil","ref":"Machete.MaybeMatcher.html","title":"Machete.MaybeMatcher","type":"module"},{"doc":"Matches against another matcher &amp; also matches nil Takes another matcher as its sole (mandatory) argument Examples: iex&gt; assert nil ~&gt; maybe ( string ( ) ) true iex&gt; assert &quot;abc&quot; ~&gt; maybe ( string ( ) ) true","ref":"Machete.MaybeMatcher.html#maybe/1","title":"Machete.MaybeMatcher.maybe/1","type":"function"},{"doc":"Describes an instance of this matcher","ref":"Machete.MaybeMatcher.html#t:t/0","title":"Machete.MaybeMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches NaiveDateTime values","ref":"Machete.NaiveDateTimeMatcher.html","title":"Machete.NaiveDateTimeMatcher","type":"module"},{"doc":"Matches against NaiveDateTime values Takes the following arguments: precision : Requires the matched NaiveDateTime to have the specified microsecond precision exactly : Requires the matched NaiveDateTime to be exactly equal to the specified NaiveDateTime roughly : Requires the matched NaiveDateTime to be within +/- 10 seconds of the specified NaiveDateTime. The atom :now can be used to use the current time as the specified NaiveDateTime before : Requires the matched NaiveDateTime to be before or equal to the specified NaiveDateTime. The atom :now can be used to use the current time as the specified NaiveDateTime after : Requires the matched NaiveDateTime to be after or equal to the specified NaiveDateTime. The atom :now can be used to use the current time as the specified NaiveDateTime Examples: iex&gt; assert NaiveDateTime . utc_now ( ) ~&gt; naive_datetime ( ) true iex&gt; assert NaiveDateTime . utc_now ( ) ~&gt; naive_datetime ( precision : 6 ) true iex&gt; assert ~N[2020-01-01 00:00:00.000000] ~&gt; naive_datetime ( exactly : ~N[2020-01-01 00:00:00.000000] ) true iex&gt; assert NaiveDateTime . utc_now ( ) ~&gt; naive_datetime ( roughly : :now ) true iex&gt; assert ~N[2020-01-01 00:00:00.000000] ~&gt; naive_datetime ( roughly : ~N[2020-01-01 00:00:05.000000] ) true iex&gt; assert ~N[2020-01-01 00:00:00.000000] ~&gt; naive_datetime ( before : :now ) true iex&gt; assert ~N[2020-01-01 00:00:00.000000] ~&gt; naive_datetime ( before : ~N[3000-01-01 00:00:00.000000] ) true iex&gt; assert ~N[3000-01-01 00:00:00.000000] ~&gt; naive_datetime ( after : :now ) true iex&gt; assert ~N[3000-01-01 00:00:00.000000] ~&gt; naive_datetime ( after : ~N[2020-01-01 00:00:00.000000] ) true","ref":"Machete.NaiveDateTimeMatcher.html#naive_datetime/1","title":"Machete.NaiveDateTimeMatcher.naive_datetime/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.NaiveDateTimeMatcher.html#t:opts/0","title":"Machete.NaiveDateTimeMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.NaiveDateTimeMatcher.html#t:t/0","title":"Machete.NaiveDateTimeMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches against a set of matchers, requiring none of them to match","ref":"Machete.NoneMatcher.html","title":"Machete.NoneMatcher","type":"module"},{"doc":"Matches against a set of matchers, requiring none of them to match Takes a list of matchers as its sole (mandatory) argument Examples: iex&gt; assert &quot;abc&quot; ~&gt; none ( [ integer ( ) , float ( ) ] ) true iex&gt; refute :abc ~&gt; all ( [ atom ( ) , string ( ) ] ) false","ref":"Machete.NoneMatcher.html#none/1","title":"Machete.NoneMatcher.none/1","type":"function"},{"doc":"Describes an instance of this matcher","ref":"Machete.NoneMatcher.html#t:t/0","title":"Machete.NoneMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches PID values","ref":"Machete.PIDMatcher.html","title":"Machete.PIDMatcher","type":"module"},{"doc":"Matches against PID values Takes no arguments Examples: iex&gt; assert self ( ) ~&gt; pid ( ) true iex&gt; refute &quot;a&quot; ~&gt; pid ( ) false","ref":"Machete.PIDMatcher.html#pid/1","title":"Machete.PIDMatcher.pid/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.PIDMatcher.html#t:opts/0","title":"Machete.PIDMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.PIDMatcher.html#t:t/0","title":"Machete.PIDMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches port values","ref":"Machete.PortMatcher.html","title":"Machete.PortMatcher","type":"module"},{"doc":"Matches against port values Takes no arguments Examples: iex&gt; assert hd ( Port . list ( ) ) ~&gt; port ( ) true iex&gt; refute &quot;a&quot; ~&gt; port ( ) false","ref":"Machete.PortMatcher.html#port/1","title":"Machete.PortMatcher.port/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.PortMatcher.html#t:opts/0","title":"Machete.PortMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.PortMatcher.html#t:t/0","title":"Machete.PortMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches reference values","ref":"Machete.ReferenceMatcher.html","title":"Machete.ReferenceMatcher","type":"module"},{"doc":"Matches against reference values Takes no arguments Examples: iex&gt; assert make_ref ( ) ~&gt; reference ( ) true iex&gt; refute &quot;a&quot; ~&gt; reference ( ) false","ref":"Machete.ReferenceMatcher.html#reference/1","title":"Machete.ReferenceMatcher.reference/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.ReferenceMatcher.html#t:opts/0","title":"Machete.ReferenceMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.ReferenceMatcher.html#t:t/0","title":"Machete.ReferenceMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches string values","ref":"Machete.StringMatcher.html","title":"Machete.StringMatcher","type":"module"},{"doc":"Matches against string values Takes the following arguments: empty : When true , requires the matched string be empty. When false, requires the matched string to be non-empty length : Requires the matched string to be exactly the specified length min : Requires the matched string to be greater than or equal to the specified length max : Requires the matched string to be less than or equal to the specified length matches : Requires the matched string to match the specified regex alphabetic : When true , requires the matched string to consist of only alphabetic characters lowercase : When true , requires the matched string to consist of only lowercase characters uppercase : When true , requires the matched string to consist of only uppercase characters alphanumeric : When true , requires the matched string to consist of only alphanumeric characters numeric : When true , requires the matched string to consist of only numeric characters hexadecimal : When true , requires the matched string to consist of only hexadecimal characters whitespace : When true , requires the string to contain whitespace (possibly in addition to other characters). When false , requires the matched string to not contain any whitespace starts_with : Requires the matched string to start with the given prefix ends_with : Requires the matched string to end with the given suffix Examples: iex&gt; assert &quot;&quot; ~&gt; string ( ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( length : 3 ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( min : 3 ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( max : 3 ) true iex&gt; assert &quot;&quot; ~&gt; string ( empty : true ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( empty : false ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( matches : ~r/abc/ ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( alphabetic : true ) true iex&gt; assert &quot;123&quot; ~&gt; string ( alphabetic : false ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( lowercase : true ) true iex&gt; assert &quot;ABC&quot; ~&gt; string ( lowercase : false ) true iex&gt; assert &quot;ABC&quot; ~&gt; string ( uppercase : true ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( uppercase : false ) true iex&gt; assert &quot;abc123&quot; ~&gt; string ( alphanumeric : true ) true iex&gt; assert &quot;$&quot; ~&gt; string ( alphanumeric : false ) true iex&gt; assert &quot;123&quot; ~&gt; string ( numeric : true ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( numeric : false ) true iex&gt; assert &quot;deadbeef0123&quot; ~&gt; string ( hexadecimal : true ) true iex&gt; assert &quot;ghi&quot; ~&gt; string ( hexadecimal : false ) true iex&gt; assert &quot;abc def&quot; ~&gt; string ( whitespace : true ) true iex&gt; assert &quot;abcdef&quot; ~&gt; string ( whitespace : false ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( starts_with : &quot;ab&quot; ) true iex&gt; assert &quot;abc&quot; ~&gt; string ( ends_with : &quot;bc&quot; ) true","ref":"Machete.StringMatcher.html#string/1","title":"Machete.StringMatcher.string/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.StringMatcher.html#t:opts/0","title":"Machete.StringMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.StringMatcher.html#t:t/0","title":"Machete.StringMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches structs only on a specified list of fields","ref":"Machete.StructMatcher.html","title":"Machete.StructMatcher","type":"module"},{"doc":"Matches structs only on a specified list of fields. Structs can be tricky to match because they have default values for fields which are not specified at the point of creation. After creation these default values are otherwise indistinguishable from user-specified ones, and often get in the way of effective matching. This matcher provides a convenient way around this by allowing the user to describe both the type of struct expected as well as a set of matchers for fields within the struct; only the fields explicitly listed in the matcher are examined. Fields can be specified via a map or keyword list in a manner identical to that of Kernel.struct/2 . Fields may be matched using any matcher, not just literal values. Examples: iex&gt; assert % URI { host : &quot;example.com&quot; , path : &quot;/abc&quot; } ~&gt; struct_like ( URI , %{ host : &quot;example.com&quot; } ) true iex&gt; assert % URI { host : &quot;example.com&quot; , path : &quot;/abc&quot; } ~&gt; struct_like ( URI , host : &quot;example.com&quot; ) true iex&gt; assert % URI { host : &quot;example.com&quot; , path : &quot;/abc&quot; } ~&gt; struct_like ( URI , host : string ( ) ) true iex&gt; refute % URI { host : &quot;example.com&quot; } ~&gt; struct_like ( URI , host : &quot;example.com&quot; , path : &quot;/abc&quot; ) false","ref":"Machete.StructMatcher.html#struct_like/2","title":"Machete.StructMatcher.struct_like/2","type":"function"},{"doc":"Describes an instance of this matcher","ref":"Machete.StructMatcher.html#t:t/0","title":"Machete.StructMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches maps which are a subset of a specified map","ref":"Machete.SubsetMatcher.html","title":"Machete.SubsetMatcher","type":"module"},{"doc":"Matches maps which are a subset of a specified map Takes a map as its sole (mandatory) argument Examples: iex&gt; assert %{ a : 1 } ~&gt; subset ( %{ a : 1 } ) true iex&gt; assert %{ a : 1 } ~&gt; subset ( %{ a : 1 , b : 1 } ) true","ref":"Machete.SubsetMatcher.html#subset/1","title":"Machete.SubsetMatcher.subset/1","type":"function"},{"doc":"Describes an instance of this matcher","ref":"Machete.SubsetMatcher.html#t:t/0","title":"Machete.SubsetMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches maps which are a superset of a specified map","ref":"Machete.SupersetMatcher.html","title":"Machete.SupersetMatcher","type":"module"},{"doc":"Matches maps which are a superset of a specified map Takes a map as its sole (mandatory) argument Examples: iex&gt; assert %{ a : 1 } ~&gt; superset ( %{ a : 1 } ) true iex&gt; assert %{ a : 1 , b : 1 } ~&gt; superset ( %{ a : 1 } ) true","ref":"Machete.SupersetMatcher.html#superset/1","title":"Machete.SupersetMatcher.superset/1","type":"function"},{"doc":"Describes an instance of this matcher","ref":"Machete.SupersetMatcher.html#t:t/0","title":"Machete.SupersetMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches everything","ref":"Machete.TermMatcher.html","title":"Machete.TermMatcher","type":"module"},{"doc":"Matches everything Takes no arguments Examples: iex&gt; assert &quot;a&quot; ~&gt; term ( ) true iex&gt; assert :a ~&gt; term ( ) true iex&gt; assert 1 ~&gt; term ( ) true iex&gt; assert %{ } ~&gt; term ( ) true iex&gt; assert nil ~&gt; term ( ) true","ref":"Machete.TermMatcher.html#term/1","title":"Machete.TermMatcher.term/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.TermMatcher.html#t:opts/0","title":"Machete.TermMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.TermMatcher.html#t:t/0","title":"Machete.TermMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches Time values","ref":"Machete.TimeMatcher.html","title":"Machete.TimeMatcher","type":"module"},{"doc":"Matches against Time values Takes the following arguments: precision : Requires the matched Time to have the specified microsecond precision exactly : Requires the matched Time to be exactly equal to the specified Time roughly : Requires the matched Time to be within +/- 10 seconds of the specified Time. The atom :now can be used to use the current time as the specified Time before : Requires the matched Time to be before or equal to the specified Time. The atom :now can be used to use the current time as the specified Time after : Requires the matched Time to be after or equal to the specified Time. The atom :now can be used to use the current time as the specified Time Examples: iex&gt; assert Time . utc_now ( ) ~&gt; time ( ) true iex&gt; assert Time . utc_now ( ) ~&gt; time ( precision : 6 ) true iex&gt; assert ~T[00:00:00.000000] ~&gt; time ( exactly : ~T[00:00:00.000000] ) true iex&gt; assert Time . utc_now ( ) ~&gt; time ( roughly : :now ) true iex&gt; assert ~T[00:00:00.000000] ~&gt; time ( roughly : ~T[00:00:05.000000] ) true iex&gt; assert ~T[00:00:00.000000] ~&gt; time ( before : :now ) true iex&gt; assert ~T[00:00:00.000000] ~&gt; time ( before : ~T[00:00:01.000000] ) true iex&gt; assert ~T[23:59:59.999999] ~&gt; time ( after : :now ) true iex&gt; assert ~T[00:00:01.000000] ~&gt; time ( after : ~T[00:00:00.000000] ) true","ref":"Machete.TimeMatcher.html#time/1","title":"Machete.TimeMatcher.time/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.TimeMatcher.html#t:opts/0","title":"Machete.TimeMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.TimeMatcher.html#t:t/0","title":"Machete.TimeMatcher.t/0","type":"opaque"},{"doc":"Defines a matcher that matches truthy values","ref":"Machete.TruthyMatcher.html","title":"Machete.TruthyMatcher","type":"module"},{"doc":"Matches against truthy values . Takes no arguments Examples: iex&gt; assert true ~&gt; truthy ( ) true iex&gt; assert 123 ~&gt; truthy ( ) true iex&gt; refute false ~&gt; truthy ( ) false iex&gt; refute nil ~&gt; truthy ( ) false","ref":"Machete.TruthyMatcher.html#truthy/1","title":"Machete.TruthyMatcher.truthy/1","type":"function"},{"doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.TruthyMatcher.html#t:opts/0","title":"Machete.TruthyMatcher.opts/0","type":"type"},{"doc":"Describes an instance of this matcher","ref":"Machete.TruthyMatcher.html#t:t/0","title":"Machete.TruthyMatcher.t/0","type":"opaque"}]